/*
 * mbed LCDWindow library
* Copyright (c) 2010 Hendrik Lipka
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/

#include "textlcdadapter.h"
#include <stdarg.h>


TextLCDAdapter::TextLCDAdapter(TextLCD_Base *lcd) {
    _lcd=lcd;
    _columns = _lcd->columns();
    _rows    = _lcd->rows();
}
void TextLCDAdapter::clear() {
    _lcd->cls();
}

void TextLCDAdapter::writeText(const unsigned int column, const unsigned int row, const char text[]){
    if ((column > getColumns()) || (row > getRows())){
        return;
    }
    _lcd->locate(column,row);
    int i=0;
    while((text[i]!=0) && (column+i < getColumns()))
    {
        _lcd->putc(text[i]);
        i++;
    }
}

void TextLCDAdapter::character(int column, int row, int c) {
    if ((column > getColumns()) || (row > getRows())){
        return;
    }
    _lcd->locate(column,row);
    _lcd->putc(c);
}

int TextLCDAdapter::putc(int c) {
    return _lcd->putc(c);
}
int TextLCDAdapter::printf(const char* format, ...) {
    // create and start the va_list
    va_list listPointer ;
    va_start( listPointer, format ) ;

    // vsprintf is an example of
    // a function that works with
    // an "already started" va_list
    static char buf[ 1024 ] ;
    vsprintf( buf, format, listPointer ) ;

    return _lcd->printf(buf);
}
